@@ -2,7 +2,7 @@
 
 # py_tools_ds
 #
-# Copyright (C) 2019  Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
+# Copyright (C) 2016-2021  Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
 #
 # This software was developed within the context of the GeoMultiSens project funded
 # by the German Federal Ministry of Education and Research
@@ -67,7 +67,6 @@ def warp_ndarray_rasterio(ndarray, in_gt, in_prj, out_prj, out_gt=None, outRowsC
     :return out_gt:             warped gdal GeoTransform
     :return out_prj:            warped projection as WKT string
     """
-
     if not find_loader('rasterio'):
         raise ImportError('This function requires rasterio. You need to install it manually '
                           '(conda install -c conda-forge rasterio). It is not automatically installed.')
@@ -75,7 +74,7 @@ def warp_ndarray_rasterio(ndarray, in_gt, in_prj, out_prj, out_gt=None, outRowsC
     # NOTE: rasterio seems to increase the number of objects with static TLS
     #       There is a maximum number and if this is exceeded an ImportError is raised:
     #       ImportError: dlopen: cannot load any more object with static TLS
-    #       - see also: https://gitext.gfz-potsdam.de/danschef/py_tools_ds/issues/8
+    #       - see also: https://git.gfz-potsdam.de/danschef/py_tools_ds/issues/8
     #       - NOTE: importing rasterio AFTER pyresample (which uses pykdtree) seems to solve that too
     #       => keep the rasterio import within the function locals to avoid not needed imports
     import rasterio
@@ -132,7 +131,6 @@ def warp_ndarray_rasterio(ndarray, in_gt, in_prj, out_prj, out_gt=None, outRowsC
 
             else:  # outRowsCols is None and outUL is None: use in_gt
                 left, bottom, right, top = gt2bounds(in_gt, rows, cols)
-                # ,im_xmax,im_ymin,im_ymax = corner_coord_to_minmax(get_corner_coordinates(self.ds_im2shift))
 
         elif out_extent:
             left, bottom, right, top = out_extent
@@ -158,8 +156,8 @@ def warp_ndarray_rasterio(ndarray, in_gt, in_prj, out_prj, out_gt=None, outRowsC
                 raise NotImplementedError('Different projections are currently not supported.')
 
             else:  # ('projected','geographic')
-                px_size_LatLon = np.array(pixelToLatLon([1, 1], geotransform=in_gt, projection=in_prj)) - \
-                                 np.array(pixelToLatLon([0, 0], geotransform=in_gt, projection=in_prj))
+                px_size_LatLon = np.array(pixelToLatLon([[1, 1]], geotransform=in_gt, projection=in_prj)) - \
+                                 np.array(pixelToLatLon([[0, 0]], geotransform=in_gt, projection=in_prj))
                 out_res = tuple(reversed(abs(px_size_LatLon)))
                 print('OUT_RES NOCHMAL CHECKEN: ', out_res)
 
@@ -255,7 +253,7 @@ def warp_ndarray(ndarray, in_gt, in_prj=None, out_prj=None, out_dtype=None,
                  out_alpha=False, targetAlignedPixels=False, gcpList=None, polynomialOrder=None, options=None,
                  transformerOptions=None, warpOptions=None, CPUs=1, warpMemoryLimit=0, progress=True, q=False):
     # type: () -> (np.ndarray, tuple, str)
-    """
+    r"""
 
     :param ndarray:             numpy array to be warped (or a list of numpy arrays (requires lists for in_gt/in_prj))
     :param in_gt:               input GDAL geotransform (or a list of GDAL geotransforms)
@@ -285,7 +283,7 @@ def warp_ndarray(ndarray, in_gt, in_prj=None, out_prj=None, out_dtype=None,
     :param options:             <str> additional GDAL options as string, e.g. '-nosrcalpha' or '-order'
     :param transformerOptions:  <list> list of transformer options, e.g.  ['SRC_SRS=invalid']
     :param warpOptions:         <list> list of warp options, e.g.  ['CUTLINE_ALL_TOUCHED=TRUE'],
-                                find available options here: http://www.gdal.org/structGDALWarpOptions.html
+                                find available options here: http://www.gdal.org/doxygen/structGDALWarpOptions.html
     :param CPUs:                <int> number of CPUs to use (default: None, which means 'all CPUs available')
     :param warpMemoryLimit:     <int> size of working buffer in bytes (default: 0)
     :param progress:            <bool> show progress bar (default: True)
